Python: module tilestache-seed

tilestache-seed | index

`tilestache-seed.py will warm your cache.
This script is intended to be run directly. This example seeds the area around
West Oakland (http://sta.mn/ck) in the "osm" layer, for zoom levels 12-15:
tilestache-seed.py -c ./config.json -l osm -b 37.79 -122.35 37.83 -122.25 -e png 12 13 14 15
See `tilestache-seed.py --help` for more information.`

Functions
`` |  | generateCoordinates(ul, lr, zooms, padding) `Generate a stream of (offset, count, coordinate) tuples for seeding. Flood-fill coordinates based on two corners, a list of zooms and padding.` listCoordinates(filename) `Generate a stream of (offset, count, coordinate) tuples for seeding. Read coordinates from a file with one Z/X/Y coordinate per line.` parseConfigfile(configpath) `Parse a configuration file and return a raw dictionary and dirpath. Return value can be passed to TileStache.Config.buildConfiguration().` tilesetCoordinates(filename) `Generate a stream of (offset, count, coordinate) tuples for seeding. Read coordinates from an MBTiles tileset filename.`

Data
`` |  | defaults = {'bbox': (37.777, -122.352, 37.839, -122.226), 'enable_retries': False, 'padding': 0, 'verbose': True} parser = <optparse.OptionParser instance> path = ['', '/Library/Frameworks/SQLite3.framework/Versions/B/Python/2.7', '/Library/Frameworks/GEOS.framework/Versions/3/Python/2.7', '/Library/Python/2.7/site-packages/numpy-override', '/Library/Frameworks/GDAL.framework/Versions/1.10/Python/2.7/site-packages', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python27.zip', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/plat-darwin', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/plat-mac', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/plat-mac/lib-scriptpackages', '/Users/migurski/Sites/TileStache/venv-tilestache/Extras/lib/python', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/lib-tk', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/lib-old', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/lib-dynload', '/System/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7', '/System/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/plat-darwin', '/System/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/lib-tk', '/System/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/plat-mac', '/System/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/plat-mac/lib-scriptpackages', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/site-packages', ...] stderr = <open file '<stderr>', mode 'w'>